==> ejc-ai-impl-3.0.0-20250327.122043-64-sources.jar: com/ejianc/foundation/ai/bean/BillInfoEntity.java <==
package com.ejianc.foundation.ai.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 单据信息表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_bill")
public class BillInfoEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="code")
    private String code; // 编码
    @TableField(value="bill_name")
    private String billName; // 单据名称
    @TableField(value="new_bill_url")
    private String newBillUrl; // 单据新增地址
    @TableField(value="detail_url")
    private String detailUrl; // 单据详情地址
    @TableField(value="create_table_sql")
    private String createTableSql; // 单据建表语句


    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public String getBillName() {
        return billName;
    }

    public void setBillName(String billName) {
        this.billName = billName;
    }
    public String getNewBillUrl() {
        return newBillUrl;
    }

    public void setNewBillUrl(String newBillUrl) {
        this.newBillUrl = newBillUrl;
    }

    public String getDetailUrl() {
        return detailUrl;
    }

    public void setDetailUrl(String detailUrl) {
        this.detailUrl = detailUrl;
    }

    public String getCreateTableSql() {
        return createTableSql;
    }

    public void setCreateTableSql(String createTableSql) {
        this.createTableSql = createTableSql;
    }
    
}

==> ejc-ai-impl-3.0.0-20250423.074155-110-sources.jar: com/ejianc/foundation/ai/bean/BillInfoEntity.java <==
package com.ejianc.foundation.ai.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 单据信息表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_bill")
public class BillInfoEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="code")
    private String code; // 编码
    @TableField(value="bill_name")
    private String billName; // 单据名称
    @TableField(value="new_bill_url")
    private String newBillUrl; // 单据新增地址
    @TableField(value="detail_url")
    private String detailUrl; // 单据详情地址
    @TableField(value="create_table_sql")
    private String createTableSql; // 单据建表语句
    @TableField(value="nodes")
    private String nodes; // 节点配置信息


    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public String getBillName() {
        return billName;
    }

    public void setBillName(String billName) {
        this.billName = billName;
    }
    public String getNewBillUrl() {
        return newBillUrl;
    }

    public void setNewBillUrl(String newBillUrl) {
        this.newBillUrl = newBillUrl;
    }

    public String getDetailUrl() {
        return detailUrl;
    }

    public void setDetailUrl(String detailUrl) {
        this.detailUrl = detailUrl;
    }

    public String getCreateTableSql() {
        return createTableSql;
    }

    public void setCreateTableSql(String createTableSql) {
        this.createTableSql = createTableSql;
    }

    public String getNodes() {
        return nodes;
    }

    public void setNodes(String nodes) {
        this.nodes = nodes;
    }
}
